Struct ConnectionPermit
pub struct ConnectionPermit { /* private fields */ }Expand description
Holds up to two semaphore permits (global + factor-specific).
Both permits are released when this value is dropped.
All-None permit fields are valid and represent the no-limits case.