build_connection_semaphore

Function build_connection_semaphore 

pub fn build_connection_semaphore(
    networking: Option<&AppState>,
    factor: &'static str,
    factor_limit: Option<usize>,
    wait_timeout: Option<Duration>,
) -> ConnectionSemaphore
Builds a ConnectionSemaphore for an outbound factor, incorporating the optional global connection limit from the networking factor’s app state.

Emits a warning when the per-factor limit exceeds the global cap (the global limit would be the effective ceiling in that case).